@@ -9,6 +9,6 @@ utils::globalVariables(c(
   "bf10", "bf_hit_3", "bf_hit_10", "log10_bf10", "mean_log10_bf", "nsims_ok",
   "scenario", "ymin", "ymax", "ymid", "p_star",
   "q05", "q25", "q50", "q75", "q95", "ci_width",
-  "mean_", "sd_"
-  # No comma after last item!
-))
+  "mean_", "sd_","hit", "hits", "trials", "lo", "hi", "sim", "n", "treatment", "age_effect",
+  "._ok_all","n_recommended","value"
+))
\ No newline at end of file
